@@ -3,14 +3,11 @@ from aiohttp import ClientSession
 from json import load, dump
 from getpass import getpass
 
-from traceback import print_exc
-
 async def login():
     try:
         return await load_creds()
     except Exception as e:
         print(str(e))
-        print_exc()
         pass
     while True:
         server = input("Enter the server URL: ")
@@ -41,5 +38,5 @@ async def load_creds():
     with open("creds.json", "r") as f:
         dc = load(f)
         client = HttpClient(dc["url"], ServerContext(cfg=dc))
-        await client.get_views()
+        await client.test_token()
         return client
\ No newline at end of file
